==> linuxconf-1.17.src.tar.gz: linuxconf-1.17/modules/managerpm/managerpm.pm <==
/* managerpm.cc 27/10/1999 23.06.30 */
PUBLIC MODULE_managerpm::MODULE_managerpm (void);
PUBLIC void MODULE_managerpm::setmenu (DIALOG&dia,
	 MENU_CONTEXT context);
PUBLIC int MODULE_managerpm::domenu (MENU_CONTEXT context,
	 const char *key);
PUBLIC int MODULE_managerpm::dohtml (const char *key);
PUBLIC void MODULE_managerpm::usage (SSTRINGS&tb);
PUBLIC int MODULE_managerpm::execmain (int argc, char *argv[]);
/* _dict.cc 16/09/1998 16.07.22 */
/* mngrpm.cc 25/11/1999 20.41.52 */
PUBLIC RPM_OPTIONS::RPM_OPTIONS (void);
PUBLIC void RPM_OPTIONS::addargs (SSTRING&args)const;
PUBLIC int PACKAGES::uninstall (void);
PUBLIC int PACKAGES::install (void);
PUBLIC void PACKAGES::unselectall (void);
PUBLIC void PACKAGES::selectall (void);
PUBLIC bool PACKAGES::any_selected (void);
PUBLIC int PACKAGES::load (const char *rpmarg, bool is_installed);
PUBLIC int PACKAGES::loadinstall (void);
PUBLIC int PACKAGES::select (const char *pattern, PACKAGES&sels);
PUBLIC void PACKAGES::remove_dups (void);
PUBLIC int PACKAGES::loadfrompath (const char *path);
PUBLIC int PACKAGES::loadfromdir (const char *dir, const char *wild);
PUBLIC PACKAGE *PACKAGES::getitem (int no)const;
PUBLIC PACKAGE *PACKAGES::locate (const char *name);
PUBLIC void PACKAGES::sort (void);
/* api.cc 25/11/1999 22.57.38 */
/* browse.cc 27/10/1999 15.56.24 */
/* package.cc 25/11/1999 23.08.50 */
PUBLIC PACKAGE::PACKAGE (const char *_name,
	 const char *_version,
	 const char *_release,
	 const char *_group,
	 const char *_vendor,
	 const char *_distribution,
	 const char *_summary);
PUBLIC PACKAGE::~PACKAGE (void);
PUBLIC int PACKAGE::uninstall (void);
PUBLIC int PACKAGE::install (void);
PUBLIC void PACKAGE::showfiles (void);
PUBLIC void PACKAGE::showinfo (void);
PUBLIC int PACKAGE::cmp (const PACKAGE *p);
PUBLIC void PACKAGE::addrequire (const char *req);
PUBLIC void PACKAGE::addprovide (const char *pro);
PUBLIC bool PACKAGE::is_needed (void)const;
PUBLIC bool PACKAGE::is_selected (void)const;
PUBLIC bool PACKAGE::is_installed (void)const;
PUBLIC void PACKAGES::resetneeded (void);
PUBLIC CONFLICT::CONFLICT (const char *key, PACKAGES *p);
PUBLIC PACKAGES *CONFLICT::getobj (void);
PUBLIC CONFLICT *CONFLICTS::getitem (int no)const;
PUBLIC bool PACKAGE::testinstall (PACKAGES&needs,
	 SSTRINGS&missing,
	 CONFLICTS&conflicts);
PUBLIC bool PACKAGE::testuninstall (PACKAGES&needs);
PUBLIC bool PACKAGES::testuninstall (bool&nodeps);
PUBLIC bool PACKAGES::testinstall (bool&nodeps, bool&replacefiles);
/* poolstr.cc 25/11/1999 23.10.00 */
PUBLIC STRENTRY::STRENTRY (const char *s);
PUBLIC STRENTRY::~STRENTRY (void);
PUBLIC void STRENTRY::addprovide (PACKAGE *p);
PUBLIC void STRENTRY::addrequire (PACKAGE *p,
	 const char *oper,
	 const char *ver);
PUBLIC STRENTRY *STRENTRIES::getitem (int no)const;
PUBLIC void STRENTRY::forgetpkg (PACKAGE *pkg);
PUBLIC void STRENTRIES::forgetpkg (PACKAGE *pkg);
PUBLIC bool STRENTRY::testinstall (PACKAGES&needs);
PUBLIC bool STRENTRY::testuninstall (PACKAGES&needs);
PUBLIC bool STRENTRY::testconflicts (const char *name,
	 PACKAGES&conflicts);

==> linuxconf-1.19.src.tar.gz: linuxconf-1.19/modules/managerpm/managerpm.pm <==
/* _dict.cc 12/12/1999 22.28.02 */
/* api.cc 09/01/2000 22.47.18 */
PACKAGES *PACKAGE_API_PRIV::loadinstalled (void);
/* browse.cc 12/12/1999 22.28.02 */
/* managerpm.cc 12/12/1999 22.28.02 */
PUBLIC MODULE_managerpm::MODULE_managerpm (void);
PUBLIC void MODULE_managerpm::setmenu (DIALOG&dia,
	 MENU_CONTEXT context);
PUBLIC int MODULE_managerpm::domenu (MENU_CONTEXT context,
	 const char *key);
PUBLIC int MODULE_managerpm::dohtml (const char *key);
PUBLIC void MODULE_managerpm::usage (SSTRINGS&tb);
PUBLIC int MODULE_managerpm::execmain (int argc, char *argv[]);
/* mngrpm.cc 09/01/2000 22.47.08 */
PUBLIC RPM_OPTIONS::RPM_OPTIONS (void);
PUBLIC void RPM_OPTIONS::addargs (SSTRING&args)const;
PUBLIC int PACKAGES::uninstall (void);
PUBLIC int PACKAGES::install (void);
PUBLIC void PACKAGES::unselectall (void);
PUBLIC void PACKAGES::selectall (void);
PUBLIC bool PACKAGES::any_selected (void);
PARSE_STATE::PARSE_STATE (int _nbpkg,
	 bool _is_installed,
	 const char *_title);
PRIVATE void PACKAGES::parse (PARSE_STATE&st, char *buf);
PUBLIC int PACKAGES::load (const char *rpmarg,
	 bool is_installed,
	 int nbpkg,
	 const char *title);
PUBLIC int PACKAGES::loadinstall (void);
PUBLIC int PACKAGES::select (const char *pattern, PACKAGES&sels);
PUBLIC void PACKAGES::remove_dups (void);
PUBLIC int PACKAGES::loadfrompath (const char *path);
PRIVATE int PACKAGES::loadfromdir_real (const char *dir,
	 const char *wild,
	 const SSTRINGS&tb);
PUBLIC int PACKAGES::loadfromdir (const char *dir, const char *wild);
PUBLIC PACKAGE *PACKAGES::getitem (int no)const;
PUBLIC PACKAGE *PACKAGES::locate (const char *name)const;
PUBLIC void PACKAGES::sort (void);
/* package.cc 09/01/2000 00.07.44 */
PUBLIC PACKAGE::PACKAGE (const char *_name,
	 const char *_version,
	 const char *_release,
	 const char *_group,
	 const char *_vendor,
	 const char *_distribution,
	 const char *_summary);
PUBLIC PACKAGE::~PACKAGE (void);
PUBLIC int PACKAGE::uninstall (void);
PUBLIC int PACKAGE::install (void);
PUBLIC void PACKAGE::showfiles (void);
PUBLIC void PACKAGE::showinfo (void);
PUBLIC int PACKAGE::cmp (const PACKAGE *p);
PUBLIC void PACKAGE::addrequire (const char *req);
PUBLIC void PACKAGE::addprovide (const char *pro);
PUBLIC bool PACKAGE::is_needed (void)const;
PUBLIC bool PACKAGE::is_selected (void)const;
PUBLIC bool PACKAGE::is_installed (void)const;
PUBLIC void PACKAGES::resetneeded (void);
PUBLIC CONFLICT::CONFLICT (const char *key, PACKAGES *p);
PUBLIC PACKAGES *CONFLICT::getobj (void);
PUBLIC CONFLICT *CONFLICTS::getitem (int no)const;
PUBLIC bool PACKAGE::testinstall (PACKAGES&needs,
	 SSTRINGS&missing,
	 CONFLICTS&conflicts);
PUBLIC bool PACKAGE::testuninstall (PACKAGES&needs);
PUBLIC bool PACKAGES::testuninstall (bool&nodeps);
PUBLIC bool PACKAGES::testinstall (bool&nodeps, bool&replacefiles);
/* poolstr.cc 12/12/1999 22.29.06 */
PUBLIC STRENTRY::STRENTRY (const char *s);
PUBLIC STRENTRY::~STRENTRY (void);
PUBLIC void STRENTRY::addprovide (PACKAGE *p);
PUBLIC void STRENTRY::addrequire (PACKAGE *p,
	 const char *oper,
	 const char *ver);
PUBLIC STRENTRY *STRENTRIES::getitem (int no)const;
PUBLIC void STRENTRY::forgetpkg (PACKAGE *pkg);
PUBLIC void STRENTRIES::forgetpkg (PACKAGE *pkg);
PUBLIC bool STRENTRY::testinstall (PACKAGES&needs);
PUBLIC bool STRENTRY::testuninstall (PACKAGES&needs);
PUBLIC bool STRENTRY::testconflicts (const char *name,
	 PACKAGES&conflicts);
